/**
 * Title: ControllerBean
 * Description: Excercise 4 - JavaBean for JSP0 training
 * Copyright:    Copyright (c) 2003
 * Company:      Master
 * @author Stefano Adriani
 * @version 1.0
 */

package adriani.tutorial.jsp ;

import javax.servlet.* ;
import javax.servlet.http.* ;
import java.util.* ;

/**
 * This bean manages the form posted by <code>form.jsp</code> page.
 *
 */
public class ControllerBean implements java.io.Serializable {

    // These fields are contained in the html form
    protected String firstName ;
    protected String lastName ;
    protected String login ;
    protected String password ;
    protected long amount ;

    // This fields are for internal use
    protected Long maxAmount ;
    protected Hashtable authentication ;
    protected Hashtable leftAmount ;


    // constructor inizializing the bean
    public ControllerBean() {

        initialize() ;
    }


    // here the bean is initialized: it should be decalerd "private" when used in real applications.
    public void initialize() {

        Long maxAmount = new Long(500) ;

        if (authentication == null) authentication = new Hashtable() ;
            else authentication.clear() ;

        authentication.put("pippo","pippo") ;
        authentication.put("pluto","pluto") ;
        authentication.put("d","d") ;

        if (leftAmount == null) leftAmount= new Hashtable() ;
            else leftAmount.clear() ;

        leftAmount.put("pippo",maxAmount) ;
        leftAmount.put("pluto",maxAmount) ;
        leftAmount.put("d",maxAmount) ;
    }


    /** This is the main method which processes the form.
    * @return <UL>
    *			<LI>0: Operation succesfull</LI>
	*			<LI>1: Wrong login</LI>
	*			<LI>2: Wrong password</LI>
	*			<LI>3: Withdraw not possible (reached maximum amount for today)</LI>
    * 		  </UL>
    */
    public long process() {

        String truePassword = (String) authentication.get(login) ;

        if (truePassword == null) return 1 ;                    // wrong login
        else if (! truePassword.equals(password)) return 2 ;    // wrong password

        if (! isPossible()) return 3 ;       // reached maxAmount for today

        long newAmount = getLeftAmount()- amount ;
        leftAmount.put(login,new Long(newAmount)) ;

        return 0 ;
    }


    // accessor method to get the left amount for today
    public long getLeftAmount() {
        Long tmp = (Long)leftAmount.get(login) ;
        if ( tmp != null) return tmp.longValue() ;
        return 0;
    }

    // here is evaluated if withdrawing is possible
    public boolean isPossible() {
        return (amount <= getLeftAmount());
    }

	// ********************* PROPERTIES METHODS *******************************

    // managing the FIRST NAME property
    public void setFirstName(String word) {
        firstName = word ;
    }

    public String getFirstName() {
         return firstName ;
    }

    // managing the LAST NAME property
    public void setLastName(String word) {
        //lastName = word ;
    }

    public String getLastName() {
         return lastName ;
    }

    // managing the LOGIN property
    public void setLogin(String word) {
        login = word ;
    }

    public String getLogin() {
         return login ;
    }

    // managing the PASSWORD property
    public void setPassword(String word) {
        password = word ;
    }

    public String getPassword() {
         return password ;
    }

    // managing the AMOUNT property
    public void setAmount(String word) {
        amount = 0 ;
        try {
            amount = Long.parseLong(word) ;
        } catch (Exception e) {
            System.out.println("!!! AMOUNT MUST BE A LONG VALUE") ;
        }
    }

    public long getAmount() {
         return amount ;
    }

}